You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by ja...@apache.org on 2017/03/16 12:10:20 UTC

[1/3] cassandra git commit: Support unaligned memory access for AArch64

Repository: cassandra
Updated Branches:
  refs/heads/cassandra-3.11 a2399d4d3 -> 6e76bbb3f
  refs/heads/trunk fe08463c3 -> 480feb01d


Support unaligned memory access for AArch64

patch by yuqi, reviewed by jasobrown for CASSANDRA-13326


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/6e76bbb3
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/6e76bbb3
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/6e76bbb3

Branch: refs/heads/cassandra-3.11
Commit: 6e76bbb3faeb91c953cb7717dbc39105eed22da9
Parents: a2399d4
Author: yuqilinaro <yu...@linaro.org>
Authored: Wed Mar 15 07:06:33 2017 +0000
Committer: Jason Brown <ja...@gmail.com>
Committed: Thu Mar 16 05:08:01 2017 -0700

----------------------------------------------------------------------
 CHANGES.txt                                           | 1 +
 src/java/org/apache/cassandra/utils/Architecture.java | 7 ++++---
 2 files changed, 5 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index ab28dd4..6d2e6c6 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,4 +1,5 @@
 3.11.0
+ * Support unaligned memory access for AArch64 (CASSANDRA-13326)
  * Improve SASI range iterator efficiency on intersection with an empty range (CASSANDRA-12915).
  * Fix equality comparisons of columns using the duration type (CASSANDRA-13174)
  * Obfuscate password in stress-graphs (CASSANDRA-12233)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/src/java/org/apache/cassandra/utils/Architecture.java
----------------------------------------------------------------------
diff --cc CHANGES.txt
index f78f6d1,6d2e6c6..24d2762
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@@ -1,49 -1,8 +1,50 @@@
 +4.0
 + * Add the currentTimestamp, currentDate, currentTime and currentTimeUUID functions (CASSANDRA-13132)
 + * Remove config option index_interval (CASSANDRA-10671)
 + * Reduce lock contention for collection types and serializers (CASSANDRA-13271)
 + * Make it possible to override MessagingService.Verb ids (CASSANDRA-13283)
 + * Avoid synchronized on prepareForRepair in ActiveRepairService (CASSANDRA-9292)
 + * Adds the ability to use uncompressed chunks in compressed files (CASSANDRA-10520)
 + * Don't flush sstables when streaming for incremental repair (CASSANDRA-13226)
 + * Remove unused method (CASSANDRA-13227)
 + * Fix minor bugs related to #9143 (CASSANDRA-13217)
 + * Output warning if user increases RF (CASSANDRA-13079)
 + * Remove pre-3.0 streaming compatibility code for 4.0 (CASSANDRA-13081)
 + * Add support for + and - operations on dates (CASSANDRA-11936)
 + * Fix consistency of incrementally repaired data (CASSANDRA-9143)
 + * Increase commitlog version (CASSANDRA-13161)
 + * Make TableMetadata immutable, optimize Schema (CASSANDRA-9425)
 + * Refactor ColumnCondition (CASSANDRA-12981)
 + * Parallelize streaming of different keyspaces (CASSANDRA-4663)
 + * Improved compactions metrics (CASSANDRA-13015)
 + * Speed-up start-up sequence by avoiding un-needed flushes (CASSANDRA-13031)
 + * Use Caffeine (W-TinyLFU) for on-heap caches (CASSANDRA-10855)
 + * Thrift removal (CASSANDRA-11115)
 + * Remove pre-3.0 compatibility code for 4.0 (CASSANDRA-12716)
 + * Add column definition kind to dropped columns in schema (CASSANDRA-12705)
 + * Add (automate) Nodetool Documentation (CASSANDRA-12672)
 + * Update bundled cqlsh python driver to 3.7.0 (CASSANDRA-12736)
 + * Reject invalid replication settings when creating or altering a keyspace (CASSANDRA-12681)
 + * Clean up the SSTableReader#getScanner API wrt removal of RateLimiter (CASSANDRA-12422)
 + * Use new token allocation for non bootstrap case as well (CASSANDRA-13080)
 + * Avoid byte-array copy when key cache is disabled (CASSANDRA-13084)
 + * Require forceful decommission if number of nodes is less than replication factor (CASSANDRA-12510)
 + * Allow IN restrictions on column families with collections (CASSANDRA-12654)
 + * Log message size in trace message in OutboundTcpConnection (CASSANDRA-13028)
 + * Add timeUnit Days for cassandra-stress (CASSANDRA-13029)
 + * Add mutation size and batch metrics (CASSANDRA-12649)
 + * Add method to get size of endpoints to TokenMetadata (CASSANDRA-12999)
 + * Expose time spent waiting in thread pool queue (CASSANDRA-8398)
 + * Conditionally update index built status to avoid unnecessary flushes (CASSANDRA-12969)
 + * cqlsh auto completion: refactor definition of compaction strategy options (CASSANDRA-12946)
 + * Add support for arithmetic operators (CASSANDRA-11935)
 + * Add histogram for delay to deliver hints (CASSANDRA-13234)
 +
 +
  3.11.0
+  * Support unaligned memory access for AArch64 (CASSANDRA-13326)
   * Improve SASI range iterator efficiency on intersection with an empty range (CASSANDRA-12915).
   * Fix equality comparisons of columns using the duration type (CASSANDRA-13174)
 - * Obfuscate password in stress-graphs (CASSANDRA-12233)
   * Move to FastThreadLocalThread and FastThreadLocal (CASSANDRA-13034)
   * nodetool stopdaemon errors out (CASSANDRA-13030)
   * Tables in system_distributed should not use gcgs of 0 (CASSANDRA-12954)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/480feb01/src/java/org/apache/cassandra/utils/Architecture.java
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index ab28dd4..6d2e6c6 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,4 +1,5 @@
 3.11.0
+ * Support unaligned memory access for AArch64 (CASSANDRA-13326)
  * Improve SASI range iterator efficiency on intersection with an empty range (CASSANDRA-12915).
  * Fix equality comparisons of columns using the duration type (CASSANDRA-13174)
  * Obfuscate password in stress-graphs (CASSANDRA-12233)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/src/java/org/apache/cassandra/utils/Architecture.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/utils/Architecture.java b/src/java/org/apache/cassandra/utils/Architecture.java
index c18185a..aa00ca1 100644
--- a/src/java/org/apache/cassandra/utils/Architecture.java
+++ b/src/java/org/apache/cassandra/utils/Architecture.java
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 
 public final class Architecture
 {
     // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
     // for those that want to run C* on this architecture at their own risk (see #11214)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",
         "x86",
         "amd64",
         "x86_64",
-        "s390x"
+        "s390x",
+        "aarch64"
     ));
 
     public static final boolean IS_UNALIGNED = UNALIGNED_ARCH.contains(System.getProperty("os.arch"));


[3/3] cassandra git commit: Merge branch 'cassandra-3.11' into trunk

Posted by ja...@apache.org.
Merge branch 'cassandra-3.11' into trunk


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/480feb01
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/480feb01
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/480feb01

Branch: refs/heads/trunk
Commit: 480feb01d749b5327cb9e4424bf2fbe2971cd364
Parents: fe08463 6e76bbb
Author: Jason Brown <ja...@gmail.com>
Authored: Thu Mar 16 05:08:39 2017 -0700
Committer: Jason Brown <ja...@gmail.com>
Committed: Thu Mar 16 05:09:43 2017 -0700

----------------------------------------------------------------------
 CHANGES.txt                                          |  1 +
 .../org/apache/cassandra/utils/Architecture.java     | 15 ++++++++-------
 2 files changed, 9 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/480feb01/CHANGES.txt
----------------------------------------------------------------------
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 public final class Architecture
 {
-    // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
-    // for those that want to run C* on this architecture at their own risk (see #11214)
+    // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
+    // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",
diff --cc src/java/org/apache/cassandra/utils/Architecture.java
index c18185a,aa00ca1..2b87de0
--- a/src/java/org/apache/cassandra/utils/Architecture.java
+++ b/src/java/org/apache/cassandra/utils/Architecture.java
@@@ -26,14 -26,15 +26,15 @@@ import com.google.common.collect.Sets
  
  public final class Architecture
  {
      // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
      // for those that want to run C* on this architecture at their own risk (see #11214)
      private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
--        "i386",
--        "x86",
--        "amd64",
--        "x86_64",
-         "s390x"
 -        "s390x",
 -        "aarch64"
++    "i386",
++    "x86",
++    "amd64",
++    "x86_64",
++    "s390x",
++    "aarch64"
      ));
  
      public static final boolean IS_UNALIGNED = UNALIGNED_ARCH.contains(System.getProperty("os.arch"));


[2/3] cassandra git commit: Support unaligned memory access for AArch64

Posted by ja...@apache.org.
Support unaligned memory access for AArch64

patch by yuqi, reviewed by jasobrown for CASSANDRA-13326


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/6e76bbb3
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/6e76bbb3
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/6e76bbb3

Branch: refs/heads/trunk
Commit: 6e76bbb3faeb91c953cb7717dbc39105eed22da9
Parents: a2399d4
Author: yuqilinaro <yu...@linaro.org>
Authored: Wed Mar 15 07:06:33 2017 +0000
Committer: Jason Brown <ja...@gmail.com>
Committed: Thu Mar 16 05:08:01 2017 -0700

----------------------------------------------------------------------
 CHANGES.txt                                           | 1 +
 src/java/org/apache/cassandra/utils/Architecture.java | 7 ++++---
 2 files changed, 5 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/CHANGES.txt
----------------------------------------------------------------------
@@@ -26,14 -26,15 +26,15 @@@ import com.google.common.collect.Sets
  public final class Architecture
  {
-     // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
-     // for those that want to run C* on this architecture at their own risk (see #11214)
+     // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
+     // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
      private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
diff --git a/src/java/org/apache/cassandra/utils/Architecture.java b/src/java/org/apache/cassandra/utils/Architecture.java
index c18185a..aa00ca1 100644
--- a/src/java/org/apache/cassandra/utils/Architecture.java
+++ b/src/java/org/apache/cassandra/utils/Architecture.java
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 
 public final class Architecture
 {
     // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
     // for those that want to run C* on this architecture at their own risk (see #11214)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",
         "x86",
         "amd64",
         "x86_64",
-        "s390x"
+        "s390x",
+        "aarch64"
     ));
 
     public static final boolean IS_UNALIGNED = UNALIGNED_ARCH.contains(System.getProperty("os.arch"));
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 public final class Architecture
 {
-    // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
-    // for those that want to run C* on this architecture at their own risk (see #11214)
+    // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
+    // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",